summaryrefslogtreecommitdiffstats
path: root/buildtools/lib/parsers/qmake/qmake_yacc.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/lib/parsers/qmake/qmake_yacc.cpp')
-rw-r--r--buildtools/lib/parsers/qmake/qmake_yacc.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/buildtools/lib/parsers/qmake/qmake_yacc.cpp b/buildtools/lib/parsers/qmake/qmake_yacc.cpp
index 718cb4f5..6824f633 100644
--- a/buildtools/lib/parsers/qmake/qmake_yacc.cpp
+++ b/buildtools/lib/parsers/qmake/qmake_yacc.cpp
@@ -19,7 +19,7 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA. */
/* As a special exception, you may create a larger work that tqcontains
part or all of the Bison parser skeleton and distribute that work
under terms of your choice, so long as that work isn't itself a
parser generator using the skeleton or a modified version thereof
@@ -679,7 +679,7 @@ namespace TQMake
depth++;
//qWarning("%s", $<value>1.ascii());
- if ((yysemantic_stack_[(4) - (1)].value).tqcontains("include"))
+ if ((yysemantic_stack_[(4) - (1)].value).contains("include"))
{
IncludeAST *includeAST = new IncludeAST();
includeAST->projectName = (yysemantic_stack_[(4) - (3)].value);
@@ -19,7 +19,7 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA. */
-/* As a special exception, you may create a larger work that tqcontains
+/* As a special exception, you may create a larger work that contains
part or all of the Bison parser skeleton and distribute that work
under terms of your choice, so long as that work isn't itself a